@@ -158,6 +158,7 @@ class PragmaExtension(ParserExtension):
         general_pragma_ranges: List[Tuple[int, int, str]],
         active_general_pragmas: Dict[str, GeneralPragmaDisableStart],
         log_pragma_failure: LogPragmaFailureProtocol,
+        actual_pragma_line_numbers: List[int],
     ) -> None:
         """
         Compile a single pragma line, validating it before adding it to the dictionary of pragmas.
@@ -171,6 +172,8 @@ class PragmaExtension(ParserExtension):
             actual_line_number = -next_line_number
             suffix_to_use = PragmaToken.pragma_alternate_suffix
 
+        actual_pragma_line_numbers.append(actual_line_number)
+
         line_after_prefix = pragma_lines[next_line_number][prefix_length:]
         after_whitespace_index, _ = ParserHelper.extract_spaces_verified(
             line_after_prefix, 0
