@@ -3,7 +3,7 @@ Module to help with the parsing of text inline elements.
 """
 
 import logging
-from typing import List, Optional, Tuple, cast
+from typing import List, Optional, Set, Tuple, cast
 
 from pymarkdown.container_blocks.parse_block_pass_properties import (
     ParseBlockPassProperties,
@@ -43,6 +43,7 @@ class InlineTextBlockHelper:
         is_setext: bool,
         para_space: Optional[str],
     ) -> Tuple[str, Optional[List[str]]]:
+
         if whitespace_to_recombine:
             source_text, _ = ParserHelper.recombine_string_with_whitespace(
                 source_text, whitespace_to_recombine
@@ -57,6 +58,34 @@ class InlineTextBlockHelper:
 
         return source_text, split_para_space
 
+    # pylint: disable=too-many-arguments
+    @staticmethod
+    def __process_inline_text_block_start(
+        parser_properties: ParseBlockPassProperties,
+        source_text: str,
+        whitespace_to_recombine: Optional[str],
+        is_para: bool,
+        is_setext: bool,
+        para_space: Optional[str],
+        start_index: int,
+    ) -> Tuple[int, Set[int], str, Optional[List[str]]]:
+        pragma_line_numbers: Set[int] = set(list(parser_properties.pragma_lines.keys()))
+
+        source_text, split_para_space = (
+            InlineTextBlockHelper.__process_inline_text_block_prepare(
+                source_text, whitespace_to_recombine, is_para, is_setext, para_space
+            )
+        )
+
+        next_index = ParserHelper.index_any_of(
+            source_text,
+            InlineHandlerHelper.valid_inline_text_block_sequence_starts,
+            start_index,
+        )
+        return next_index, pragma_line_numbers, source_text, split_para_space
+
+    # pylint: enable=too-many-arguments
+
     # pylint: disable=too-many-arguments, too-many-locals
     @staticmethod  # noqa: C901
     def process_inline_text_block(  # noqa: C901
@@ -88,21 +117,21 @@ class InlineTextBlockHelper:
             current_string_unresolved,
         ) = (line_number, column_number, "", "")
         start_index = 0
+        newlines_encountered = 0
         inline_blocks: List[MarkdownToken] = []
         end_string: Optional[str] = ""
 
-        source_text, split_para_space = (
-            InlineTextBlockHelper.__process_inline_text_block_prepare(
-                source_text, whitespace_to_recombine, is_para, is_setext, para_space
+        next_index, pragma_line_numbers, source_text, split_para_space = (
+            InlineTextBlockHelper.__process_inline_text_block_start(
+                parser_properties,
+                source_text,
+                whitespace_to_recombine,
+                is_para,
+                is_setext,
+                para_space,
+                start_index,
             )
         )
-
-        next_index = ParserHelper.index_any_of(
-            source_text,
-            InlineHandlerHelper.valid_inline_text_block_sequence_starts,
-            start_index,
-        )
-        newlines_encountered = 0
         while next_index != -1:
             old_next_index = next_index
             (
@@ -140,6 +169,7 @@ class InlineTextBlockHelper:
                 tabified_text,
                 newlines_encountered,
                 is_in_table,
+                pragma_line_numbers,
                 para_space,
             )
             if adj_newlines:
@@ -187,6 +217,7 @@ class InlineTextBlockHelper:
         tabified_text: Optional[str],
         newlines_encountered: int,
         is_in_table: bool,
+        pragma_line_numbers: Set[int],
         para_space: Optional[str] = None,
     ) -> Tuple[
         int,
@@ -260,6 +291,7 @@ class InlineTextBlockHelper:
             para_owner,
             tabified_text,
             tabified_remaining_line,
+            pragma_line_numbers,
         )
 
         (
@@ -325,6 +357,7 @@ class InlineTextBlockHelper:
             last_line_number,
             last_column_number,
             end_string,
+            pragma_line_numbers,
         )
 
         return (
@@ -576,6 +609,7 @@ class InlineTextBlockHelper:
         para_owner: Optional[ParagraphMarkdownToken],
         tabified_text: Optional[str],
         tabified_remaining_line: Optional[str],
+        pragma_line_numbers: Set[int],
     ) -> Tuple[
         InlineResponse,
         int,
@@ -606,6 +640,7 @@ class InlineTextBlockHelper:
                 line_number,
                 column_number,
                 coalesced_stack,
+                pragma_line_numbers,
             )
             if inline_response.reduce_remaining_line_by:
                 (
@@ -811,6 +846,7 @@ class InlineTextBlockHelper:
         last_line_number: int,
         last_column_number: int,
         end_string: Optional[str],
+        pragma_line_numbers: Set[int],
     ) -> Tuple[
         int,
         int,
@@ -836,6 +872,7 @@ class InlineTextBlockHelper:
             remaining_line,
             did_line_number_change,
             was_column_number_reset,
+            pragma_line_numbers,
         )
 
         (
@@ -905,6 +942,7 @@ class InlineTextBlockHelper:
         remaining_line: str,
         did_line_number_change: bool,
         was_column_number_reset: bool,
+        pragma_line_numbers: Set[int],
     ) -> Tuple[int, int, Optional[List[str]]]:
         if was_new_line:
             column_number = 1
@@ -926,6 +964,8 @@ class InlineTextBlockHelper:
                 column_number += selected_split_length
 
             line_number += 1
+            while line_number in pragma_line_numbers:
+                line_number += 1
             assert (
                 split_para_space
             ), "If we had a new line, we must have paragraph/setext text to handle."
