@@ -93,7 +93,7 @@ class RuleMd031(RulePlugin):
             plugin_id="MD031",
             plugin_enabled_by_default=True,
             plugin_description="Fenced code blocks should be surrounded by blank lines",
-            plugin_version="0.7.0",
+            plugin_version="0.7.1",
             plugin_url="https://pymarkdown.readthedocs.io/en/latest/plugins/rule_md031.md",
             plugin_configuration="list_items",
             plugin_supports_fix=True,
@@ -1199,12 +1199,25 @@ class RuleMd031(RulePlugin):
                 self.__fix_spacing(context, token, False, False)
             else:
                 assert self.__last_non_end_token
+                if self.__last_non_end_token.is_text:
+                    text_token = cast(TextMarkdownToken, self.__last_non_end_token)
+                    override_is_error_token_prefaced_by_blank_line = (
+                        text_token.token_text.endswith(
+                            ParserHelper.newline_character
+                            + ParserHelper.replace_noop_character
+                        )
+                    )
+                else:
+                    override_is_error_token_prefaced_by_blank_line = False
                 line_number_delta, column_number_delta = self.__calculate_end_deltas()
+                error_token = self.__end_fenced_code_block_token.start_markdown_token
                 self.report_next_token_error(
                     context,
-                    self.__end_fenced_code_block_token.start_markdown_token,
-                    line_number_delta=line_number_delta,
+                    error_token,
+                    line_number_delta=line_number_delta
+                    + context.calc_pragma_offset(error_token, line_number_delta),
                     column_number_delta=column_number_delta,
+                    override_is_error_token_prefaced_by_blank_line=override_is_error_token_prefaced_by_blank_line,
                 )
         self.__end_fenced_code_block_token = None
 
