@@ -2,7 +2,9 @@
 Module to provide for an encapsulation of the table header markdown token.
 """
 
-from typing import List, Optional, cast
+from typing import List, Optional, Union, cast
+
+from typing_extensions import override
 
 from pymarkdown.general.parser_helper import ParserHelper
 from pymarkdown.general.position_marker import PositionMarker
@@ -101,7 +103,7 @@ class TableMarkdownToken(LeafMarkdownToken):
         next_token: MarkdownToken,
         transform_state: TransformState,
     ) -> str:
-        _ = (transform_state, next_token)
+        _ = next_token
 
         token_parts: List[str] = []
         if (
@@ -135,25 +137,48 @@ class TableMarkdownHeaderToken(LeafMarkdownToken):
         separator_table_row: TableRow,
         position_marker: PositionMarker,
     ) -> None:
+        self.__header_row_leading_whitespace: Optional[str] = None
+        self.__header_row_trailing_whitespace: Optional[str] = None
+        self.__did_header_row_start_with_separator = False
+        self.__separator_line: Optional[str] = None
         if header_table_row:
-            self.header_row_leading_whitespace = header_table_row.extracted_whitespace
-            self.header_row_trailing_whitespace = header_table_row.trailing_whitespace
-            self.did_header_row_start_with_separator = (
+            self.__header_row_leading_whitespace = header_table_row.extracted_whitespace
+            self.__header_row_trailing_whitespace = header_table_row.trailing_whitespace
+            self.__did_header_row_start_with_separator = (
                 header_table_row.did_start_with_separator
             )
-            self.separator_table_row = separator_table_row
+            self.__separator_line = TableMarkdownHeaderToken.__xx(separator_table_row)
+
         LeafMarkdownToken.__init__(
             self,
             MarkdownToken._token_table_header,
-            extra_data=None,
+            extra_data=self.__compose_extra_data_field(),
             position_marker=position_marker,
             extracted_whitespace="",
             requires_end_token=True,
         )
 
-        # header_row_leading_whitespace
-        # did_header_row_start_with_separator
-        # header_row_trailing_whitespace
+    def __compose_extra_data_field(self) -> Optional[str]:
+        """
+        Compose the object's self.extra_data field from the local object's variables.
+        """
+        if self.__header_row_leading_whitespace is None:
+            self._set_extra_data(None)
+            return None
+
+        assert self.__header_row_trailing_whitespace is not None
+        assert self.__header_row_trailing_whitespace is not None
+        assert self.__separator_line is not None
+        composed_field = MarkdownToken.extra_data_separator.join(
+            [
+                self.__header_row_leading_whitespace,
+                self.__header_row_trailing_whitespace,
+                str(self.__did_header_row_start_with_separator),
+                self.__separator_line,
+            ]
+        )
+        self._set_extra_data(composed_field)
+        return composed_field
 
     # pylint: disable=protected-access
     @staticmethod
@@ -165,6 +190,45 @@ class TableMarkdownHeaderToken(LeafMarkdownToken):
 
     # pylint: enable=protected-access
 
+    @property
+    def header_row_leading_whitespace(self) -> str:
+        """Gets any leading whitespace for the header row."""
+        assert self.__header_row_leading_whitespace is not None
+        return self.__header_row_leading_whitespace
+
+    @property
+    def header_row_trailing_whitespace(self) -> str:
+        """Gets any trailing whitespace for the header row."""
+        assert self.__header_row_trailing_whitespace is not None
+        return self.__header_row_trailing_whitespace
+
+    @property
+    def did_header_row_start_with_separator(self) -> bool:
+        """Gets a value indicating whether the header row started with a separator."""
+        return self.__did_header_row_start_with_separator
+
+    @property
+    def separator_line(self) -> str:
+        """Gets the separator line between the header and the body of the table."""
+        assert self.__separator_line is not None
+        return self.__separator_line
+
+    @override
+    def _modify_token(self, field_name: str, field_value: Union[str, int]) -> bool:
+        if field_name == "header_row_leading_whitespace" and isinstance(
+            field_value, str
+        ):
+            self.__header_row_leading_whitespace = field_value
+            extra_data = self.__compose_extra_data_field()
+            super()._set_extra_data(extra_data)
+            return True
+        if field_name == "separator_line" and isinstance(field_value, str):
+            self.__separator_line = field_value
+            extra_data = self.__compose_extra_data_field()
+            super()._set_extra_data(extra_data)
+            return True
+        return super()._modify_token(field_name, field_value)
+
     def register_for_markdown_transform(
         self, registration_function: RegisterMarkdownTransformHandlersProtocol
     ) -> None:
@@ -192,6 +256,7 @@ class TableMarkdownHeaderToken(LeafMarkdownToken):
         header_start_text = cast(
             TableMarkdownHeaderToken, current_token
         ).header_row_leading_whitespace
+        assert header_start_text is not None
         return header_start_text + (
             "|"
             if cast(
@@ -200,6 +265,15 @@ class TableMarkdownHeaderToken(LeafMarkdownToken):
             else ""
         )
 
+    @staticmethod
+    def __xx(separator_table_row: TableRow) -> str:
+        header_end_text = separator_table_row.extracted_whitespace
+        header_end_text += "|" if separator_table_row.did_start_with_separator else ""
+        for i in separator_table_row.columns:
+            header_end_text += i.leading_whitespace + i.text + i.trailing_whitespace
+        header_end_text += separator_table_row.trailing_whitespace
+        return header_end_text
+
     @staticmethod
     def __rehydrate_table_header_end(
         context: MarkdownTransformContext,
@@ -216,13 +290,10 @@ class TableMarkdownHeaderToken(LeafMarkdownToken):
             TableMarkdownHeaderToken,
             cast(EndMarkdownToken, current_token).start_markdown_token,
         )
-        header_end_text = start_token.separator_table_row.extracted_whitespace
-        header_end_text += (
-            "|" if start_token.separator_table_row.did_start_with_separator else ""
-        )
-        for i in start_token.separator_table_row.columns:
-            header_end_text += i.leading_whitespace + i.text + i.trailing_whitespace
-        header_end_text += start_token.separator_table_row.trailing_whitespace
+
+        header_end_text = start_token.separator_line
+        assert start_token.header_row_trailing_whitespace is not None
+        assert header_end_text is not None
         return (
             start_token.header_row_trailing_whitespace + "\n" + header_end_text + "\n"
         )
@@ -286,17 +357,26 @@ class TableMarkdownHeaderItemToken(LeafMarkdownToken):
         self,
         leading_whitespace: str,
         column_alignment: Optional[str],
-        position_marker: PositionMarker,
+        line_number: int,
+        column_number: int,
     ) -> None:
+        self.__leading_whitespace: str = leading_whitespace
+        self.__column_alignment = column_alignment
         LeafMarkdownToken.__init__(
             self,
             MarkdownToken._token_table_header_item,
-            extra_data=column_alignment,
-            position_marker=position_marker,
+            extra_data=self.__compose_extra_data_field(),
+            line_number=line_number,
+            column_number=column_number,
             extracted_whitespace=leading_whitespace,
             requires_end_token=True,
         )
 
+    @property
+    def column_alignment(self) -> Optional[str]:
+        """Gets the alignment of this header's column."""
+        return self.__column_alignment
+
     # pylint: disable=protected-access
     @staticmethod
     def get_markdown_token_type() -> str:
@@ -307,6 +387,19 @@ class TableMarkdownHeaderItemToken(LeafMarkdownToken):
 
     # pylint: enable=protected-access
 
+    def __compose_extra_data_field(self) -> Optional[str]:
+        """
+        Compose the object's self.extra_data field from the local object's variables.
+        """
+        composed_field = MarkdownToken.extra_data_separator.join(
+            [
+                self.__leading_whitespace,
+                self.__column_alignment if self.__column_alignment is not None else "",
+            ]
+        )
+        self._set_extra_data(composed_field)
+        return composed_field
+
     def register_for_markdown_transform(
         self, registration_function: RegisterMarkdownTransformHandlersProtocol
     ) -> None:
@@ -365,8 +458,9 @@ class TableMarkdownHeaderItemToken(LeafMarkdownToken):
     ) -> str:
         _ = (transform_state, next_token)
 
-        if next_token.extra_data:
-            text_to_add = f'<th align="{next_token.extra_data}">'
+        table_token = cast(TableMarkdownHeaderItemToken, next_token)
+        if table_token.column_alignment:
+            text_to_add = f'<th align="{table_token.column_alignment}">'
         else:
             text_to_add = "<th>"
         return "".join(
@@ -398,15 +492,13 @@ class TableMarkdownBodyToken(LeafMarkdownToken):
     Class to provide for an encapsulation of the table header markdown token.
     """
 
-    def __init__(
-        self,
-        position_marker: PositionMarker,
-    ) -> None:
+    def __init__(self, line_number: int, column_number: int) -> None:
         LeafMarkdownToken.__init__(
             self,
             MarkdownToken._token_table_body,
             extra_data=None,
-            position_marker=position_marker,
+            line_number=line_number,
+            column_number=column_number,
             extracted_whitespace="",
             requires_end_token=True,
         )
@@ -510,23 +602,69 @@ class TableMarkdownRowToken(LeafMarkdownToken):
         trailing_whitespace: str,
         did_start_with_separator: bool,
         delta: int,
-        position_marker: PositionMarker,
+        line_number: int,
+        column_number: int,
     ) -> None:
-        self.leading_whitespace = leading_whitespace
-        self.trailing_whitespace = trailing_whitespace
-        self.did_start_with_separator = did_start_with_separator
-        self.delta = delta
+        self.__leading_whitespace = leading_whitespace
+        self.__trailing_whitespace = trailing_whitespace
+        self.__did_start_with_separator = did_start_with_separator
+        self.__delta = delta
         LeafMarkdownToken.__init__(
             self,
             MarkdownToken._token_table_row,
-            extra_data=None,
-            position_marker=position_marker,
+            extra_data=self.__compose_extra_data_field(),
+            line_number=line_number,
+            column_number=column_number,
             extracted_whitespace="",
             requires_end_token=True,
         )
 
     # pylint: enable=too-many-arguments
 
+    def __compose_extra_data_field(self) -> Optional[str]:
+        """
+        Compose the object's self.extra_data field from the local object's variables.
+        """
+        composed_field = MarkdownToken.extra_data_separator.join(
+            [
+                self.__leading_whitespace,
+                self.__trailing_whitespace,
+                str(self.__did_start_with_separator),
+                str(self.__delta),
+            ]
+        )
+        self._set_extra_data(composed_field)
+        return composed_field
+
+    @property
+    def leading_whitespace(self) -> str:
+        """Gets any leading whitespace for this row."""
+        return self.__leading_whitespace
+
+    @property
+    def trailing_whitespace(self) -> str:
+        """Gets any trailing whitespace for this row."""
+        return self.__trailing_whitespace
+
+    @property
+    def did_start_with_separator(self) -> bool:
+        """Gets a value indicating whether the row started with a separator character."""
+        return self.__did_start_with_separator
+
+    @property
+    def delta(self) -> int:
+        """Gets the delta columns to add to ensure that this row has the required number of columns."""
+        return self.__delta
+
+    @override
+    def _modify_token(self, field_name: str, field_value: Union[str, int]) -> bool:
+        if field_name == "leading_whitespace" and isinstance(field_value, str):
+            self.__leading_whitespace = field_value
+            extra_data = self.__compose_extra_data_field()
+            super()._set_extra_data(extra_data)
+            return True
+        return super()._modify_token(field_name, field_value)
+
     # pylint: disable=protected-access
     @staticmethod
     def get_markdown_token_type() -> str:
@@ -645,17 +783,31 @@ class TableMarkdownRowItemToken(LeafMarkdownToken):
         self,
         leading_whitespace: str,
         column_alignment: Optional[str],
-        position_marker: PositionMarker,
+        line_number: int,
+        column_number: int,
     ) -> None:
+        self.__leading_whitespace: str = leading_whitespace
+        self.__column_alignment = column_alignment
         LeafMarkdownToken.__init__(
             self,
             MarkdownToken._token_table_row_item,
-            extra_data=column_alignment,
-            position_marker=position_marker,
+            extra_data=self.__compose_extra_data_field(),
+            line_number=line_number,
+            column_number=column_number,
             extracted_whitespace=leading_whitespace,
             requires_end_token=True,
         )
 
+    @property
+    def leading_whitespace(self) -> str:
+        """Get the leading whitespace for this row item's text."""
+        return self.__leading_whitespace
+
+    @property
+    def column_alignment(self) -> Optional[str]:
+        """Get the alignment of this row item's column."""
+        return self.__column_alignment
+
     # pylint: disable=protected-access
     @staticmethod
     def get_markdown_token_type() -> str:
@@ -666,6 +818,19 @@ class TableMarkdownRowItemToken(LeafMarkdownToken):
 
     # pylint: enable=protected-access
 
+    def __compose_extra_data_field(self) -> Optional[str]:
+        """
+        Compose the object's self.extra_data field from the local object's variables.
+        """
+        composed_field = MarkdownToken.extra_data_separator.join(
+            [
+                self.leading_whitespace,
+                self.column_alignment if self.column_alignment is not None else "",
+            ]
+        )
+        self._set_extra_data(composed_field)
+        return composed_field
+
     def register_for_markdown_transform(
         self, registration_function: RegisterMarkdownTransformHandlersProtocol
     ) -> None:
@@ -688,7 +853,7 @@ class TableMarkdownRowItemToken(LeafMarkdownToken):
         Rehydrate the link reference definition from the token.
         """
         _ = (previous_token, current_token, context)
-        return cast(TableMarkdownRowItemToken, current_token).extracted_whitespace
+        return cast(TableMarkdownRowItemToken, current_token).leading_whitespace
 
     @staticmethod
     def __rehydrate_table_row_item_end(
@@ -724,8 +889,9 @@ class TableMarkdownRowItemToken(LeafMarkdownToken):
     ) -> str:
         _ = (transform_state, next_token)
 
-        if next_token.extra_data:
-            text_to_add = f'<td align="{next_token.extra_data}">'
+        table_token = cast(TableMarkdownRowItemToken, next_token)
+        if table_token.column_alignment:
+            text_to_add = f'<td align="{table_token.column_alignment}">'
         else:
             text_to_add = "<td>"
         return "".join(
